# -*- coding: utf-8 -*-
"""
@author: cwilhelm 2020

vspace package init file.

"""

from __future__ import absolute_import, division, print_function, unicode_literals

__version__ = "1.0.1"
__author__ = "Caitlyn Wilhelm (cwilhelm@uw.edu)"
__copyright__ = "Copyright 2020  Caitlyn Wilhelm"

from .vspace import *
